@@ -160,7 +160,7 @@ edit_command (GtkWidget * button, gpointer data) {
     }
 
     const gchar *editor = getenv("EDITOR");
-    if (!editor && strlen(editor)==0){
+    if (!editor || strlen(editor)==0){
 	rfm_diagnostics(widgets_p, "xffm/stock_dialog-warning",NULL);
 	rfm_diagnostics(widgets_p, "xffm_tag/stderr", _("No editor component found."), "\n", NULL);
 	return;
@@ -594,6 +594,7 @@ create_find_dialog () {
     GtkAccelGroup *accel_group = gtk_accel_group_new ();
 
     GtkWidget *dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_window_set_type_hint(GTK_WINDOW(dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
     GdkGeometry geometry;
     rfm_get_drawable_geometry (gdk_x11_get_default_root_xwindow (), 
 	    NULL, NULL, &(geometry.max_width), &(geometry.max_height), NULL);
@@ -669,7 +670,6 @@ create_find_dialog () {
     gtk_widget_show (label42);
     gtk_box_pack_start (GTK_BOX (hbox), label42, FALSE, FALSE, 0);
     gtk_label_set_use_markup (GTK_LABEL (label42), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label42), 0, 0.5);
 
     GtkWidget *button;
 
@@ -849,7 +849,6 @@ create_find_dialog () {
     gtk_widget_show (contains_label);
     gtk_box_pack_start (GTK_BOX (top_pane_vbox), contains_label, FALSE, FALSE, 1);
     gtk_label_set_use_markup (GTK_LABEL (contains_label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (contains_label), 0, 0.5);
 
     GtkWidget *hbox26 = rfm_hbox_new (FALSE, 0);
     gtk_widget_show (hbox26);
@@ -946,7 +945,6 @@ create_find_dialog () {
     g_free(t);
     gtk_widget_show (label40);
     gtk_box_pack_start (GTK_BOX (hbox24), label40, FALSE, FALSE, 0);
-    gtk_misc_set_padding (GTK_MISC (label40), 3, 0);
     gtk_widget_set_sensitive (label40, FALSE);
     g_object_set_data(G_OBJECT(dialog), "label40", label40);
 
@@ -1069,8 +1067,10 @@ create_find_dialog () {
 	if (strchr(basename, ' ')) *strchr(basename, ' ') = 0;
 	gchar *editor_path = g_find_program_in_path(basename);
 	if (editor_path){
-	    gchar *iconpath=ICON_get_filename_from_basename(basename);
-	    if (!iconpath) iconpath = g_strdup("xffm/stock_edit");
+	    gchar *iconpath=g_strdup(basename);
+	    GdkPixbuf *pix = rfm_get_pixbuf (iconpath, SMALL_ICON_SIZE); //refs
+	    if (!pix) iconpath = g_strdup("xffm/stock_edit");
+            else g_object_unref(pix);
 
 	    GtkWidget *edit_button = 
                 rfm_dialog_button(iconpath, _("Edit"));
