@@ -46,7 +46,7 @@ critical_module_error(const gchar *mod){
 
 static void
 finishit (int sig) {
-    TRACE ("ZZZ got signal %d\n", sig);
+    fprintf (stderr,"finish it: got signal %d\n", sig);
     DBG ("ZZZ got signal %d (SIGUSR1=%d,SIGUSR2=%d)\n", sig, SIGUSR1, SIGUSR2);
     if(sig == SIGUSR1) {
         return;
@@ -101,7 +101,7 @@ signal_connections (void
 
 //      sigaction(SIGHUP,&act,NULL);
       sigaction(SIGTERM,&act,NULL);
-# ifndef DEBUG
+# ifndef CORE 
 //      sigaction(SIGINT,&act,NULL);
 //      sigaction(SIGQUIT,&act,NULL);
 //      sigaction(SIGABRT,&act,NULL);
@@ -115,7 +115,7 @@ signal_connections (void
 #else
 //      signal(SIGHUP, finishit);
       signal(SIGTERM, finishit);
-# ifndef DEBUG
+# ifndef CORE
 //      signal(SIGINT, finishit);
 //      signal(SIGQUIT, finishit);
 //      signal(SIGABRT, finishit);
@@ -306,6 +306,19 @@ static void cleanup(void){
 }   
 
   
+static void
+kill_anim(void){
+    pid_t pid = fork();
+    if (!pid){
+        DBG("Stopping animation...\n");
+        gchar *a[]={"/bin/sh", "-c", "killall rodent-anim 2>/dev/null", NULL};
+        execvp("/bin/sh", a);
+        _exit(123);
+    }
+    gint status;
+    waitpid(pid, &status, 0);
+}
+
 
 static gboolean
 do_setup(void *data){
@@ -407,7 +420,8 @@ do_setup(void *data){
    }
     TRACE("rfm_global_p->window=0x%x\n", GPOINTER_TO_INT(rfm_global_p->window));
     if (!rfm_global_p->window) {
-	critical_module_error((strstr(argv[0], "rodent-desk"))?"deskview":"gridview");
+	kill_anim();
+        critical_module_error((strstr(argv[0], "rodent-desk"))?"deskview":"gridview");
     }
     SETWD();
 
@@ -418,17 +432,7 @@ do_setup(void *data){
     // janitor_thread termination.
     rfm_thread_create ("janitor", janitor, rfm_global_p->window, FALSE);
 
-    //if (animation_pid) kill(animation_pid, SIGKILL); else 
-    {
-	    pid_t pid = fork();
-	    if (!pid){
-		gchar *a[]={"/bin/sh", "-c", "killall rodent-anim 2>/dev/null", NULL};
-		execvp("/bin/sh", a);
-		_exit(123);
-	    }
-	    gint status;
-	    waitpid(pid, &status, 0);
-    }
+    kill_anim();
             
     gchar *prg = g_path_get_basename(rfm_global_p->argv[0]);
 
@@ -437,6 +441,7 @@ do_setup(void *data){
     } else if(getenv ("RFM_ENABLE_DESKTOP") && strlen (getenv ("RFM_ENABLE_DESKTOP"))){
         enable_desktop = GPOINTER_TO_INT(rfm_void(RFM_MODULE_DIR, "settings", "localhost_check"));
     }
+    g_free(prg);
 
     TRACE (">>>> enable_desktop=%d\n", enable_desktop);
 
@@ -545,6 +550,7 @@ main (int argc, char *argv[]) {
 	    anim_OK = TRUE;
 	}
     }
+    g_free(b);
     if (anim_OK)
     {
 	animation_pid = fork();
@@ -588,7 +594,7 @@ main (int argc, char *argv[]) {
 #if defined TCMALLOC 
     g_warning("TCMALLOC enabled: sudo/ssh password dialog will not operate (if started from a tty)!\n");
 #else
-    
+   
     if(strstr (argv[0], "rodent-getpass") == NULL)
     {
 	if(fork ()){
@@ -621,15 +627,18 @@ main (int argc, char *argv[]) {
 #ifdef CORE
     struct rlimit rlim;
     if (!strstr(argv[0], "getpass")) {
-	DBG("Enabling core dumps...\n");
+	fprintf(stderr, "Enabling core dumps...\n");
     }
     rlim.rlim_cur = RLIM_INFINITY;
     rlim.rlim_max = RLIM_INFINITY;
     setrlimit (RLIMIT_CORE, &rlim);
 #endif
 
-    rfm_global_init (argc, argv);
+    // argv is checked for validity before passing to chdir, 
+    // so this coverity issue can be ignored.
+    // coverity[tainted_string : FALSE]
     process_arg (&argc, &argv);
+    rfm_global_init (argc, argv);
     if(!g_module_supported ()) {
         g_error ("g_module_supported() != TRUE\n");
         exit (1);
