@@ -409,8 +409,8 @@ find_path (GtkTreeModel * treemodel, GtkTreePath * treepath, GtkTreeIter * iter,
 
 static gboolean
 find_row (GtkTreeModel * treemodel, GtkTreePath * treepath, GtkTreeIter * iter, gpointer data) {
-    char *id = data;
-    char *n;
+    const gchar *id = data;
+    gchar *n;
 
     if(name_found)
         return TRUE;
@@ -434,7 +434,7 @@ find_row (GtkTreeModel * treemodel, GtkTreePath * treepath, GtkTreeIter * iter,
         else if (icon_name) {
             gtk_tree_model_foreach ((GtkTreeModel *) store2, find_path, icon_name);
             if(path_found) {
-                if (!id) TRACE ("%s: generic icon path_found=%s\n", icon_name, path_found);
+                //if (!id) NOOP ("%s: generic icon path_found=%s\n", icon_name, path_found);
                 GdkPixbuf *icon = rfm_get_pixbuf (path_found, RODENT_MIME_ICON_SIZE);
                 if(icon) {
                     gtk_tree_store_set ((GtkTreeStore *) store, iter, 
@@ -456,7 +456,7 @@ find_row (GtkTreeModel * treemodel, GtkTreePath * treepath, GtkTreeIter * iter,
             }
         } 
 
-        /*TRACE("duplicate %s==%s, looking for icon %s\n",n,name,id); */
+        //NOOP("duplicate %s==%s, looking for icon %s\n",n,name,id); 
         name_found = TRUE;
     }
 
@@ -754,11 +754,12 @@ make_dialog (gchar * txt) {
     GdkPixbuf *pb;
     static GdkCursor *cursor = NULL;
     if(!cursor)
-        cursor = gdk_cursor_new (GDK_WATCH);
+        cursor = gdk_cursor_new_for_display (gdk_display_get_default(),GDK_WATCH);
 
     if(!get_xml_files ())
         return NULL;
     dialog = gtk_dialog_new ();
+    gtk_window_set_type_hint(GTK_WINDOW(dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
     GtkWidget *vbox = rfm_vbox_new(FALSE, 2);
     gtk_box_pack_end (GTK_BOX (
 		gtk_dialog_get_content_area(GTK_DIALOG (dialog))), 
@@ -1084,6 +1085,13 @@ main (int argc, char *argv[]) {
     rodent_init();   
     gtk_init (&argc, &argv);
 
+    const gchar *use_icontheme = getenv("RFM_USE_GTK_ICON_THEME");
+    if (!use_icontheme || !strlen(use_icontheme)){
+        const gchar *text = _("Please activate icontheme specification in rodent-fm preferences dialog.");
+        rfm_confirm(NULL, GTK_MESSAGE_ERROR, text, NULL, NULL);
+        exit(1);
+    }
+
 
     signal_connections ();
     /* read in shm settings: this will also pull in icon module... */
