@@ -3,7 +3,9 @@ $nproc=4;
 print "Using $nproc threads\n";
 $n=0;
 $top=`pwd`; chop $top;
-@subdirs = ( "apps/fgr", "apps/rodent-fgr", "apps/rodent-diff", "apps/rodent-iconmgr",  "apps/rodent-fm","apps/rodent-pkg", "./");
+@subdirs = ( "apps/fgr", "apps/rodent-fgr", "apps/rodent-diff", "apps/rodent-iconmgr",  "apps/rodent-fm","apps/rodent-pkg", 
+        "apps/rodent-fstab", "apps/rodent-fuse", "apps/rodent-ps",
+        "apps/rodent-samba", "apps/rodent-dotdesktop", "./");
 BEGIN { $| = 1 }
 $j=0;
 foreach $subdir (@subdirs){
